Crate kcr_topology_node_k8s_io

Crate kcr_topology_node_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the topology.node.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

topology.node.k8s.io/v1alpha1

  • NodeResourceTopology

Modules

v1alpha1